Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2757)

Unified Diff: ash/display/display_manager.h

Issue 657583003: Chrome OS: Ash support for >=3 displays. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: rebase again to resolve conflicts at TOT Created 6 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | ash/display/display_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/display/display_manager.h
diff --git a/ash/display/display_manager.h b/ash/display/display_manager.h
index b7aef5fc5ecae7ecc6bc02ee692d56983c4cb106..97558ccb476820db86d9edc5fd940abc11e4907b 100644
--- a/ash/display/display_manager.h
+++ b/ash/display/display_manager.h
@@ -343,13 +343,15 @@ private:
// Creates a display object from the DisplayInfo for |display_id|.
gfx::Display CreateDisplayFromDisplayInfoById(int64 display_id);
- // Updates the bounds of the secondary display in |display_list|
- // using the layout registered for the display pair and set the
- // index of display updated to |updated_index|. Returns true
- // if the secondary display's bounds has been changed from current
- // value, or false otherwise.
- bool UpdateSecondaryDisplayBoundsForLayout(DisplayList* display_list,
- size_t* updated_index) const;
+ // Updates the bounds of all non-primary displays in |display_list| and
+ // append the indices of displays updated to |updated_indices|.
+ // When the size of |display_list| equals 2, the bounds are updated using
+ // the layout registered for the display pair. For more than 2 displays,
+ // the bounds are updated using horizontal layout.
+ // Returns true if any of the non-primary display's bounds has been changed
+ // from current value, or false otherwise.
+ bool UpdateNonPrimaryDisplayBoundsForLayout(
+ DisplayList* display_list, std::vector<size_t>* updated_indices) const;
void CreateMirrorWindowIfAny();
« no previous file with comments | « no previous file | ash/display/display_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698